@@ -5,7 +5,7 @@ CONFIGH=${CONFIGH_ABS_PATH:-../config.h}
 
 UG="$UGREP --color=always --sort $@"
 
-FILES="Hello.bat Hello.class Hello.java Hello.pdf Hello.sh Hello.txt"
+FILES="Hello.bat Hello.class Hello.java Hello.pdf Hello.sh Hello.txt empty.txt emptyline.txt"
 
 if test ! -x "$UGREP" ; then
   echo "$UGREP not found, exiting"
@@ -218,7 +218,7 @@ $UG --range=1,1   Hello $FILES \
 for PAT in '' 'Hello' '\w+\s+\S+' '\S\n\S' 'nomatch' ; do
   FN=`echo "Hello_$PAT" | tr -Cd '[:alnum:]_'`
   for OUT in '' '-I' '-W' '-X' ; do
-    for OPS in '' '-l' '-lv' '-c' '-co' '-cv' '-n' '-nkbT' '-unkbT' '-o' '-on' '-onkbT' '-ounkbT' '-v' '-nv' '-C2' '-nC2' '-vC2' '-nvC2' '-y' '-ny' '-vy' '-nvy' ; do
+    for OPS in '' '-l' '-lv' '-c' '-co' '-cv' '-n' '-nkbT' '-unkbT' '-o' '-on' '-onkbT' '-ounkbT' '-v' '-nv' '-C2' '-nC2' '-vC2' '-nvC2' '-onC10' '-y' '-ny' '-vy' '-nvy' ; do
       printf .
       $UG -U $OUT $OPS "$PAT" $FILES \
         | $DIFF "out/$FN$OUT$OPS.out" \
